@@ -5,24 +5,35 @@ Provides both sync (`RunloopSDK`) and async (`AsyncRunloopSDK`) interfaces.
 
 from __future__ import annotations
 
-from .sync import DevboxOps, RunloopSDK, SnapshotOps, BlueprintOps, StorageObjectOps
+from .sync import AgentOps, DevboxOps, ScorerOps, RunloopSDK, ScenarioOps, SnapshotOps, BlueprintOps, StorageObjectOps
+from .agent import Agent
 from .async_ import (
+    AsyncAgentOps,
     AsyncDevboxOps,
+    AsyncScorerOps,
     AsyncRunloopSDK,
+    AsyncScenarioOps,
     AsyncSnapshotOps,
     AsyncBlueprintOps,
     AsyncStorageObjectOps,
 )
-from .devbox import Devbox
+from .devbox import Devbox, NamedShell
+from .scorer import Scorer
+from .scenario import Scenario
 from .snapshot import Snapshot
 from .blueprint import Blueprint
 from .execution import Execution
-from .async_devbox import AsyncDevbox
+from .async_agent import AsyncAgent
+from .async_devbox import AsyncDevbox, AsyncNamedShell
+from .async_scorer import AsyncScorer
+from .scenario_run import ScenarioRun
+from .async_scenario import AsyncScenario
 from .async_snapshot import AsyncSnapshot
 from .storage_object import StorageObject
 from .async_blueprint import AsyncBlueprint
 from .async_execution import AsyncExecution
 from .execution_result import ExecutionResult
+from .async_scenario_run import AsyncScenarioRun
 from .async_storage_object import AsyncStorageObject
 from .async_execution_result import AsyncExecutionResult
 
@@ -31,15 +42,23 @@ __all__ = [
     "RunloopSDK",
     "AsyncRunloopSDK",
     # Management interfaces
+    "AgentOps",
+    "AsyncAgentOps",
     "DevboxOps",
     "AsyncDevboxOps",
     "BlueprintOps",
     "AsyncBlueprintOps",
+    "ScenarioOps",
+    "AsyncScenarioOps",
+    "ScorerOps",
+    "AsyncScorerOps",
     "SnapshotOps",
     "AsyncSnapshotOps",
     "StorageObjectOps",
     "AsyncStorageObjectOps",
     # Resource classes
+    "Agent",
+    "AsyncAgent",
     "Devbox",
     "AsyncDevbox",
     "Execution",
@@ -48,8 +67,16 @@ __all__ = [
     "AsyncExecutionResult",
     "Blueprint",
     "AsyncBlueprint",
+    "Scenario",
+    "AsyncScenario",
+    "ScenarioRun",
+    "AsyncScenarioRun",
+    "Scorer",
+    "AsyncScorer",
     "Snapshot",
     "AsyncSnapshot",
     "StorageObject",
     "AsyncStorageObject",
+    "NamedShell",
+    "AsyncNamedShell",
 ]
