@@ -1,26 +1,30 @@
 from typing import Union, Callable, Optional
 from typing_extensions import TypedDict
 
-from runloop_api_client.types.devboxes import DiskSnapshotUpdateParams
-
 from .._types import Body, Query, Headers, Timeout, NotGiven
 from ..lib.polling import PollingConfig
+from ..types.devboxes import DiskSnapshotListParams, DiskSnapshotUpdateParams
+from ..types.scenarios import ScorerListParams, ScorerCreateParams, ScorerUpdateParams, ScorerValidateParams
+from ..types.agent_list_params import AgentListParams
 from ..types.devbox_list_params import DevboxListParams
 from ..types.object_list_params import ObjectListParams
+from ..types.agent_create_params import AgentCreateParams
 from ..types.devbox_create_params import DevboxCreateParams, DevboxBaseCreateParams
 from ..types.object_create_params import ObjectCreateParams
+from ..types.scenario_list_params import ScenarioListParams
 from ..types.blueprint_list_params import BlueprintListParams
 from ..types.object_download_params import ObjectDownloadParams
+from ..types.scenario_update_params import ScenarioUpdateParams
 from ..types.blueprint_create_params import BlueprintCreateParams
 from ..types.devbox_upload_file_params import DevboxUploadFileParams
+from ..types.scenario_start_run_params import ScenarioStartRunBaseParams
 from ..types.devbox_create_tunnel_params import DevboxCreateTunnelParams
 from ..types.devbox_download_file_params import DevboxDownloadFileParams
-from ..types.devbox_execute_async_params import DevboxExecuteAsyncParams
+from ..types.devbox_execute_async_params import DevboxNiceExecuteAsyncParams
 from ..types.devbox_remove_tunnel_params import DevboxRemoveTunnelParams
 from ..types.devbox_snapshot_disk_params import DevboxSnapshotDiskParams
 from ..types.devbox_read_file_contents_params import DevboxReadFileContentsParams
 from ..types.devbox_write_file_contents_params import DevboxWriteFileContentsParams
-from ..types.devboxes.disk_snapshot_list_params import DiskSnapshotListParams
 
 LogCallback = Callable[[str], None]
 
@@ -36,7 +40,7 @@ class ExecuteStreamingCallbacks(TypedDict, total=False):
     """Callback invoked for all log lines (both stdout and stderr)"""
 
 
-class RequestOptions(TypedDict, total=False):
+class BaseRequestOptions(TypedDict, total=False):
     extra_headers: Optional[Headers]
     """Send extra headers"""
 
@@ -50,12 +54,12 @@ class RequestOptions(TypedDict, total=False):
     """Override the client-level default timeout for this request, in seconds"""
 
 
-class LongRequestOptions(RequestOptions, total=False):
+class LongRequestOptions(BaseRequestOptions, total=False):
     idempotency_key: Optional[str]
     """Specify a custom idempotency key for this request"""
 
 
-class PollingRequestOptions(RequestOptions, total=False):
+class PollingRequestOptions(BaseRequestOptions, total=False):
     polling_config: Optional[PollingConfig]
     """Configuration for polling behavior"""
 
@@ -72,15 +76,15 @@ class SDKDevboxCreateFromImageParams(DevboxBaseCreateParams, LongPollingRequestO
     pass
 
 
-class SDKDevboxExecuteParams(DevboxExecuteAsyncParams, ExecuteStreamingCallbacks, LongPollingRequestOptions):
+class SDKDevboxExecuteParams(DevboxNiceExecuteAsyncParams, ExecuteStreamingCallbacks, LongPollingRequestOptions):
     pass
 
 
-class SDKDevboxExecuteAsyncParams(DevboxExecuteAsyncParams, ExecuteStreamingCallbacks, LongRequestOptions):
+class SDKDevboxExecuteAsyncParams(DevboxNiceExecuteAsyncParams, ExecuteStreamingCallbacks, LongRequestOptions):
     pass
 
 
-class SDKDevboxListParams(DevboxListParams, RequestOptions):
+class SDKDevboxListParams(DevboxListParams, BaseRequestOptions):
     pass
 
 
@@ -116,7 +120,7 @@ class SDKDevboxSnapshotDiskParams(DevboxSnapshotDiskParams, LongPollingRequestOp
     pass
 
 
-class SDKDiskSnapshotListParams(DiskSnapshotListParams, RequestOptions):
+class SDKDiskSnapshotListParams(DiskSnapshotListParams, BaseRequestOptions):
     pass
 
 
@@ -128,11 +132,11 @@ class SDKBlueprintCreateParams(BlueprintCreateParams, LongPollingRequestOptions)
     pass
 
 
-class SDKBlueprintListParams(BlueprintListParams, RequestOptions):
+class SDKBlueprintListParams(BlueprintListParams, BaseRequestOptions):
     pass
 
 
-class SDKObjectListParams(ObjectListParams, RequestOptions):
+class SDKObjectListParams(ObjectListParams, BaseRequestOptions):
     pass
 
 
@@ -140,5 +144,45 @@ class SDKObjectCreateParams(ObjectCreateParams, LongRequestOptions):
     pass
 
 
-class SDKObjectDownloadParams(ObjectDownloadParams, RequestOptions):
+class SDKObjectDownloadParams(ObjectDownloadParams, BaseRequestOptions):
+    pass
+
+
+class SDKScorerCreateParams(ScorerCreateParams, LongRequestOptions):
+    pass
+
+
+class SDKScorerListParams(ScorerListParams, BaseRequestOptions):
+    pass
+
+
+class SDKScorerUpdateParams(ScorerUpdateParams, LongRequestOptions):
+    pass
+
+
+class SDKScorerValidateParams(ScorerValidateParams, LongRequestOptions):
+    pass
+
+
+class SDKAgentCreateParams(AgentCreateParams, LongRequestOptions):
+    pass
+
+
+class SDKAgentListParams(AgentListParams, BaseRequestOptions):
+    pass
+
+
+class SDKScenarioListParams(ScenarioListParams, BaseRequestOptions):
+    pass
+
+
+class SDKScenarioUpdateParams(ScenarioUpdateParams, LongRequestOptions):
+    pass
+
+
+class SDKScenarioRunAsyncParams(ScenarioStartRunBaseParams, LongRequestOptions):
+    pass
+
+
+class SDKScenarioRunParams(ScenarioStartRunBaseParams, LongPollingRequestOptions):
     pass
