@@ -7,7 +7,7 @@ import logging
 from typing import Optional, Awaitable, cast
 from typing_extensions import Unpack, override
 
-from ._types import RequestOptions, LongRequestOptions
+from ._types import BaseRequestOptions, LongRequestOptions
 from .._client import AsyncRunloop
 from .async_execution_result import AsyncExecutionResult
 from ..types.devbox_async_execution_detail_view import DevboxAsyncExecutionDetailView
@@ -43,7 +43,7 @@ class AsyncExecution:
     terminate the running process. Created by ``await devbox.cmd.exec_async()``.
 
     Example:
-        >>> execution = await devbox.cmd.exec_async(command="python train.py")
+        >>> execution = await devbox.cmd.exec_async("python train.py")
         >>> state = await execution.get_state()
         >>> if state.status == "running":
         ...     await execution.kill()
@@ -119,7 +119,7 @@ class AsyncExecution:
         final = cast(DevboxAsyncExecutionDetailView, command_result)
         return AsyncExecutionResult(self._client, self._devbox_id, final)
 
-    async def get_state(self, **options: Unpack[RequestOptions]) -> DevboxAsyncExecutionDetailView:
+    async def get_state(self, **options: Unpack[BaseRequestOptions]) -> DevboxAsyncExecutionDetailView:
         """Fetch the latest execution state.
 
         :param options: Optional request configuration
