@@ -15,7 +15,7 @@ from ..types import (
 )
 from ._types import (
     LogCallback,
-    RequestOptions,
+    BaseRequestOptions,
     LongRequestOptions,
     PollingRequestOptions,
     SDKDevboxExecuteParams,
@@ -34,12 +34,11 @@ from ._types import (
 from .._client import Runloop
 from ._helpers import filter_params
 from .execution import Execution, _StreamingGroup
-from .protocols import FileInterface, CommandInterface, NetworkInterface
 from .._streaming import Stream
 from ..lib.polling import PollingConfig
+from ..types.devboxes import ExecutionUpdateChunk
 from .execution_result import ExecutionResult
-from ..types.devbox_execute_async_params import DevboxExecuteAsyncParams
-from ..types.devboxes.execution_update_chunk import ExecutionUpdateChunk
+from ..types.devbox_execute_async_params import DevboxNiceExecuteAsyncParams
 from ..types.devbox_async_execution_detail_view import DevboxAsyncExecutionDetailView
 
 if TYPE_CHECKING:
@@ -55,7 +54,7 @@ class Devbox:
     The Devbox class supports context manager protocol for automatic cleanup.
 
     Example:
-        >>> with sdk.devbox.create(name="my-devbox") as devbox:
+        >>> with runloop.devbox.create(name="my-devbox") as devbox:
         ...     result = devbox.cmd.exec("echo 'hello'")
         ...     print(result.stdout())
         # Devbox is automatically shutdown on exit
@@ -103,13 +102,13 @@ class Devbox:
 
     def get_info(
         self,
-        **options: Unpack[RequestOptions],
+        **options: Unpack[BaseRequestOptions],
     ) -> DevboxView:
         """Retrieve current devbox status and metadata.
 
         :param options: Optional request configuration
         :return: Current devbox state info
-        :rtype: DevboxView
+        :rtype: :class:`~runloop_api_client.types.devbox_view.DevboxView`
         """
         return self._client.devboxes.retrieve(
             self._id,
@@ -124,7 +123,7 @@ class Devbox:
         :param polling_config: Optional configuration for polling behavior (timeout, interval), defaults to None
         :type polling_config: PollingConfig | None, optional
         :return: Devbox state info after it reaches running status
-        :rtype: DevboxView
+        :rtype: :class:`~runloop_api_client.types.devbox_view.DevboxView`
         """
         return self._client.devboxes.await_running(self._id, polling_config=polling_config)
 
@@ -136,7 +135,7 @@ class Devbox:
         :param polling_config: Optional configuration for polling behavior (timeout, interval), defaults to None
         :type polling_config: PollingConfig | None, optional
         :return: Devbox state info after it reaches suspended status
-        :rtype: DevboxView
+        :rtype: :class:`~runloop_api_client.types.devbox_view.DevboxView`
         """
         return self._client.devboxes.await_suspended(self._id, polling_config=polling_config)
 
@@ -148,7 +147,7 @@ class Devbox:
 
         :param options: Long-running request configuration (timeouts, retries, etc.)
         :return: Final devbox state info
-        :rtype: DevboxView
+        :rtype: :class:`~runloop_api_client.types.devbox_view.DevboxView`
         """
         return self._client.devboxes.shutdown(
             self._id,
@@ -166,7 +165,7 @@ class Devbox:
 
         :param options: Optional long-running request and polling configuration
         :return: Suspended devbox state info
-        :rtype: DevboxView
+        :rtype: :class:`~runloop_api_client.types.devbox_view.DevboxView`
         """
         self._client.devboxes.suspend(
             self._id,
@@ -184,7 +183,7 @@ class Devbox:
 
         :param options: Optional long-running request and polling configuration
         :return: Resumed devbox state info
-        :rtype: DevboxView
+        :rtype: :class:`~runloop_api_client.types.devbox_view.DevboxView`
         """
         self._client.devboxes.resume(
             self._id,
@@ -261,7 +260,7 @@ class Devbox:
         :return: Helper for running shell commands
         :rtype: CommandInterface
         """
-        return _CommandInterface(self)
+        return CommandInterface(self)
 
     @property
     def file(self) -> FileInterface:
@@ -270,7 +269,7 @@ class Devbox:
         :return: Helper for reading/writing files
         :rtype: FileInterface
         """
-        return _FileInterface(self)
+        return FileInterface(self)
 
     @property
     def net(self) -> NetworkInterface:
@@ -279,7 +278,40 @@ class Devbox:
         :return: Helper for SSH keys and tunnels
         :rtype: NetworkInterface
         """
-        return _NetworkInterface(self)
+        return NetworkInterface(self)
+
+    def shell(self, shell_name: str | None = None) -> NamedShell:
+        """Create a named shell instance for stateful command execution.
+
+        Named shells are stateful and maintain environment variables and the current working
+        directory (CWD) across commands, just like a real shell on your local computer.
+        Commands executed through the same named shell instance will execute sequentially -
+        the shell can only run one command at a time with automatic queuing. This ensures
+        that environment changes and directory changes from one command are preserved for
+        the next command.
+
+        :param shell_name: The name of the persistent shell session. If not provided, a UUID will be generated automatically.
+        :type shell_name: str | None, optional
+        :return: A NamedShell instance for executing commands in the named shell
+        :rtype: NamedShell
+
+        Example:
+            >>> # Create a named shell with a custom name
+            >>> shell = devbox.shell("my-session")
+            >>> # Create a named shell with an auto-generated UUID name
+            >>> shell2 = devbox.shell()
+            >>> # Commands execute sequentially and share state
+            >>> shell.exec("cd /app")
+            >>> shell.exec("export MY_VAR=value")
+            >>> result = shell.exec("echo $MY_VAR")  # Will output 'value'
+            >>> result = shell.exec("pwd")  # Will output '/app'
+        """
+        if shell_name is None:
+            # uuid_utils is not typed
+            from uuid_utils import uuid7  # type: ignore
+
+            shell_name = str(uuid7())
+        return NamedShell(self, shell_name)
 
     # --------------------------------------------------------------------- #
     # Internal helpers
@@ -375,7 +407,7 @@ class Devbox:
         return thread
 
 
-class _CommandInterface:
+class CommandInterface:
     """Interface for executing commands on a devbox.
 
     Accessed via devbox.cmd property. Provides exec() for synchronous execution
@@ -387,6 +419,7 @@ class _CommandInterface:
 
     def exec(
         self,
+        command: str,
         **params: Unpack[SDKDevboxExecuteParams],
     ) -> ExecutionResult:
         """Execute a command synchronously and wait for completion.
@@ -396,7 +429,7 @@ class _CommandInterface:
         :rtype: ExecutionResult
 
         Example:
-            >>> result = devbox.cmd.exec(command="ls -la")
+            >>> result = devbox.cmd.exec("ls -la")
             >>> print(result.stdout())
             >>> print(f"Exit code: {result.exit_code}")
         """
@@ -405,7 +438,8 @@ class _CommandInterface:
 
         execution: DevboxAsyncExecutionDetailView = client.devboxes.execute_async(
             devbox.id,
-            **filter_params(params, DevboxExecuteAsyncParams),
+            command=command,
+            **filter_params(params, DevboxNiceExecuteAsyncParams),
             **filter_params(params, LongRequestOptions),
         )
         streaming_group = devbox._start_streaming(
@@ -430,6 +464,7 @@ class _CommandInterface:
 
     def exec_async(
         self,
+        command: str,
         **params: Unpack[SDKDevboxExecuteAsyncParams],
     ) -> Execution:
         """Execute a command asynchronously without waiting for completion.
@@ -443,7 +478,7 @@ class _CommandInterface:
         :rtype: Execution
 
         Example:
-            >>> execution = devbox.cmd.exec_async(command="sleep 10")
+            >>> execution = devbox.cmd.exec_async("sleep 10")
             >>> state = execution.get_state()
             >>> print(f"Status: {state.status}")
             >>> execution.kill()  # Terminate early if needed
@@ -453,7 +488,8 @@ class _CommandInterface:
 
         execution: DevboxAsyncExecutionDetailView = client.devboxes.execute_async(
             devbox.id,
-            **filter_params(params, DevboxExecuteAsyncParams),
+            command=command,
+            **filter_params(params, DevboxNiceExecuteAsyncParams),
             **filter_params(params, LongRequestOptions),
         )
 
@@ -465,7 +501,7 @@ class _CommandInterface:
         return Execution(client, devbox.id, execution, streaming_group)
 
 
-class _FileInterface:
+class FileInterface:
     """Interface for file operations on a devbox.
 
     Accessed via devbox.file property. Provides methods for reading, writing,
@@ -504,7 +540,7 @@ class _FileInterface:
 
         :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKDevboxWriteFileContentsParams` for available parameters
         :return: Execution metadata for the write command
-        :rtype: DevboxExecutionDetailView
+        :rtype: :class:`~runloop_api_client.types.devbox_execution_detail_view.DevboxExecutionDetailView`
 
         Example:
             >>> devbox.file.write(file_path="/home/user/config.json", contents='{"key": "value"}')
@@ -555,7 +591,104 @@ class _FileInterface:
         )
 
 
-class _NetworkInterface:
+class NamedShell:
+    """Interface for executing commands in a persistent, stateful shell session.
+
+    Named shells are stateful and maintain environment variables and the current working
+    directory (CWD) across commands. Commands executed through the same named shell
+    instance will execute sequentially - the shell can only run one command at a time
+    with automatic queuing. This ensures that environment changes and directory changes
+    from one command are preserved for the next command.
+
+    Use :meth:`Devbox.shell` to create a named shell instance. If you use the same shell
+    name, it will re-attach to the existing named shell, preserving its state.
+
+    Example:
+        >>> shell = devbox.shell("my-session")
+        >>> shell.exec("cd /app")
+        >>> shell.exec("export MY_VAR=value")
+        >>> result = shell.exec("echo $MY_VAR")  # Will output 'value'
+        >>> result = shell.exec("pwd")  # Will output '/app'
+    """
+
+    def __init__(self, devbox: Devbox, shell_name: str) -> None:
+        """Initialize the named shell.
+
+        :param devbox: The devbox instance to execute commands on
+        :type devbox: Devbox
+        :param shell_name: The name of the persistent shell session
+        :type shell_name: str
+        """
+        self._devbox = devbox
+        self._shell_name = shell_name
+
+    def exec(
+        self,
+        command: str,
+        **params: Unpack[SDKDevboxExecuteParams],
+    ) -> ExecutionResult:
+        """Execute a command in the named shell and wait for it to complete.
+
+        The command will execute in the persistent shell session, maintaining environment
+        variables and the current working directory from previous commands. Commands are
+        queued and execute sequentially - only one command runs at a time in the named shell.
+
+        Optionally provide callbacks to stream logs in real-time. When callbacks are provided,
+        this method waits for both the command to complete AND all streaming data to be
+        processed before returning.
+
+        :param command: The command to execute
+        :type command: str
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKDevboxExecuteParams` for available parameters
+        :return: Wrapper with exit status and output helpers
+        :rtype: ExecutionResult
+
+        Example:
+            >>> shell = devbox.shell("my-session")
+            >>> result = shell.exec("ls -la")
+            >>> print(result.stdout())
+            >>> # With streaming callbacks
+            >>> result = shell.exec("npm install", stdout=lambda line: print(f"[LOG] {line}"))
+        """
+        # Ensure shell_name is set and cannot be overridden by user params
+        params["shell_name"] = self._shell_name
+        return self._devbox.cmd.exec(command, **params)
+
+    def exec_async(
+        self,
+        command: str,
+        **params: Unpack[SDKDevboxExecuteAsyncParams],
+    ) -> Execution:
+        """Execute a command in the named shell asynchronously without waiting for completion.
+
+        The command will execute in the persistent shell session, maintaining environment
+        variables and the current working directory from previous commands. Commands are
+        queued and execute sequentially - only one command runs at a time in the named shell.
+
+        Optionally provide callbacks to stream logs in real-time as they are produced.
+        Callbacks fire in real-time as logs arrive. When you call execution.result(),
+        it will wait for both the command to complete and all streaming to finish.
+
+        :param command: The command to execute
+        :type command: str
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKDevboxExecuteAsyncParams` for available parameters
+        :return: Handle for managing the running process
+        :rtype: Execution
+
+        Example:
+            >>> shell = devbox.shell("my-session")
+            >>> execution = shell.exec_async("long-running-task.sh", stdout=lambda line: print(f"[LOG] {line}"))
+            >>> # Do other work while command runs...
+            >>> result = execution.result()
+            >>> if result.success:
+            ...     print("Task completed successfully!")
+        """
+        # Ensure shell_name is set and cannot be overridden by user params
+        params["shell_name"] = self._shell_name
+        return self._devbox.cmd.exec_async(command, **params)
+
+
+class NetworkInterface:
     """Interface for network operations on a devbox.
 
     Accessed via devbox.net property. Provides methods for SSH access and tunneling.
@@ -572,7 +705,7 @@ class _NetworkInterface:
 
         :param options: Optional long-running request configuration
         :return: Response containing SSH connection info
-        :rtype: DevboxCreateSSHKeyResponse
+        :rtype: :class:`~runloop_api_client.types.devbox_create_ssh_key_response.DevboxCreateSSHKeyResponse`
 
         Example:
             >>> ssh_key = devbox.net.create_ssh_key()
@@ -591,7 +724,7 @@ class _NetworkInterface:
 
         :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKDevboxCreateTunnelParams` for available parameters
         :return: Details about the public endpoint
-        :rtype: DevboxTunnelView
+        :rtype: :class:`~runloop_api_client.types.devbox_tunnel_view.DevboxTunnelView`
 
         Example:
             >>> tunnel = devbox.net.create_tunnel(port=8080)
